@@ -3,20 +3,24 @@
  *  R
  *
  *  Created by Simon Urbanek on 10/23/08.
- *  Copyright 2008-2016 R Foundation for Statistical Computing. All rights reserved.
+ *  Copyright 2008-2017 R Foundation for Statistical Computing. All rights reserved.
  *
  */
 
 /* GUI version as shown in infos e.g. 1.27-devel */
-#define GUI_VER 1.68
+#define GUI_VER 1.70
 /* R postfix used to denote release versions of GUI - set to R release version (e.g. 2.8.0) or to anything that will be shown in between R and GUI (e.g. - or for Mac) */
-#define R_RELEASE 3.3.0
+#define R_RELEASE 3.4.1
 
 #if RELEASE_CFG
 /* for release config just auto-detect the SDK used */
 /* we cannot use Availability.h because of the odd processing Xcode uses here! */
 #define MIN_VER __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__
-#if MIN_VER >= 1090
+#if MIN_VER >= 1011
+#define CFG_NAME El Capitan build
+#elif MIN_VER >= 1010
+#define CFG_NAME Yosemite build
+#elif MIN_VER >= 1090
 #define CFG_NAME Mavericks build
 #elif MIN_VER >= 1080
 #define CFG_NAME Mountain Lion build
